@@ -19,14 +19,14 @@ class MagicianGoApi(object):
                                                         y=y,
                                                         r=r)
 
-    def set_rotate_deg_speed(self, port_name, r, vr):
+    def set_rotate_deg_speed(self, port_name, r, Vr):
         return self.__dobotlink.MagicianGO.SetMoveDistance(portName=port_name,
                                                            r=r,
-                                                           vr=vr)
+                                                           Vr=Vr)
 
-    def set_xy_speed_distance(self, port_name, x, y, vx, vy):
+    def set_xy_speed_distance(self, port_name, x, y, Vx, Vy):
         return self.__dobotlink.MagicianGO.SetFixedOrientationMoveDistance(
-            portName=port_name, x=x, y=y, vx=vx, vy=vy)
+            portName=port_name, x=x, y=y, Vx=Vx, Vy=Vy)
 
     def moveto_destination(self, port_name, x, y, s):
         return self.__dobotlink.MagicianGO.SetWorldCoordinateMovePoint(
